@@ -181,6 +181,18 @@ class I2AOauth2Client:
         else:
             raise I2AOauth2ClientException(data=response.json())
 
+    def deactivate_account(self, token):
+        url = self._get_full_url('application-users/deactivate-account/')
+        headers = self.headers.copy()
+        headers['Authorization'] = f"Bearer {token}"
+        response = requests.delete(url, headers=headers)
+        if response.status_code == 204:
+            return
+        elif response.status_code == 500:
+            raise I2AOauth2ClientException(f'Deactivate account attempt at {url} has failed for unknown reason.')
+        else:
+            raise I2AOauth2ClientException(data=response.json())
+
     def delete_account(self, token):
         url = self._get_full_url('application-users/delete-account/')
         headers = self.headers.copy()
